=============
 Development
=============

This document provides information about developing gevent itself,
including information about running tests.

More information is in the ``CONTRIBUTING.rst`` document in the root
of the gevent repository.

.. toctree::
   :maxdepth: 2

   getting_started
   installing_from_source
   running_tests
   ci
   release_process

..
    The contributor guide (CONTRIBUTING.rst) references this document.

    Things to include:

    - Custom commands in ``setup.py``
